@@ -341,7 +341,7 @@ bool Box_Data::confirm_discard_unstored_data() const
     Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("No primary key value")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
     dialog.set_secondary_text(_("This data cannot be stored in the database because you have not provided a primary key.\nDo you really want to discard this data?"));
     //TODO: It needs a const. I wonder if it should. murrayc. dialog.set_transient_for(*get_app_window());
-    int iButton = dialog.run();
+    const int iButton = dialog.run();
 
     return (iButton == Gtk::RESPONSE_OK);
   }
@@ -624,71 +624,6 @@ g_warning("debug: Box_Data::get_field()");
 }
 */
 
-/*
-Glib::ustring Box_Data::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause)
-{
-  Glib::ustring result;
-
-  Document_Glom* document = get_document();
-
-  Glib::ustring sql_part_fields;
-
-  typedef std::list<Relationship> type_list_relationships;
-  type_list_relationships list_relationships;
-
-  for(type_vecLayoutFields::const_iterator iter =  fieldsToGet.begin(); iter != fieldsToGet.end(); ++iter)
-  {
-    if(iter != fieldsToGet.begin())
-      sql_part_fields += ", ";
-
-
-    if(!iter->get_has_relationship_name())
-    {
-      sql_part_fields += ( table_name + "." );
-    }
-    else
-    {
-      Glib::ustring relationship_name = iter->get_relationship_name();
-      Relationship relationship;
-      bool test = document->get_relationship(table_name, relationship_name, relationship);
-      if(test)
-      {
-        const Glib::ustring field_table_name = relationship->get_to_table();
-        sql_part_fields += ( field_table_name + "." );
-
-        //Add the relationship to the list:
-        type_list_relationships::const_iterator iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_FieldHasName<Relationship>( relationship_name ) );
-        if(iterFind == list_relationships.end()) //If the table is not yet in the list:
-          list_relationships.push_back(relationship);
-      }
-    }
-
-    sql_part_fields += iter->get_name();
-  }
-
-  result =  "SELECT " + sql_part_fields +
-    " FROM \"" + table_name + "\"";
-
-  //LEFT OUTER JOIN will get the field values from the other tables, and give us our fields for this table even if there is no corresponding value in the other table.
-  Glib::ustring sql_part_leftouterjoin; 
-  for(type_list_relationships::const_iterator iter = list_relationships.begin(); iter != list_relationships.end(); ++iter)
-  {
-    const Relationship& relationship = *iter;
-    sql_part_leftouterjoin += " LEFT OUTER JOIN " + relationship->get_to_table() +
-      " ON (" + relationship->get_from_table() + "." + relationship->get_from_field() + " = " +
-      relationship->get_to_table() + "." + relationship->get_to_field() +
-      ")";
-  }
-
-  result += sql_part_leftouterjoin;
-
-  if(!where_clause.empty())
-    result += " WHERE " + where_clause;
-
-  return result;
-}
-*/
-
 bool Box_Data::get_related_record_exists(const sharedptr<const Relationship>& relationship, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_value)
 {
   bool result = false;
@@ -696,9 +631,10 @@ bool Box_Data::get_related_record_exists(const sharedptr<const Relationship>& re
   //TODO_Performance: It's very possible that this is slow.
   //We don't care how many records there are, only whether there are more than zero.
   const Glib::ustring to_field = relationship->get_to_field();
+  const Glib::ustring related_table = relationship->get_to_table();
 
   //TODO_Performance: Is this the best way to just find out whether there is one record that meets this criteria?
-  const Glib::ustring query = "SELECT \"" + to_field + "\" FROM \"" + relationship->get_to_table() + "\" WHERE \"" + to_field + "\" = " + key_field->sql(key_value);
+  const Glib::ustring query = "SELECT \"" + to_field + "\" FROM \"" + relationship->get_to_table() + "\" WHERE \"" + related_table + "\".\"" + to_field + "\" = " + key_field->sql(key_value);
   Glib::RefPtr<Gnome::Gda::DataModel> records = query_execute(query, get_app_window());
   if(!records)
     handle_error();
